/**
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005 Emic Networks
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Marc Herbert
 * Contributor(s): 
 */

#ifndef TESTSIMPLEUNICODE_H_
#define TESTSIMPLEUNICODE_H_

#include "../ConnectionSetup.hpp"

/**
 * Unicode support testing.
 * TODO: add more tests
 */
class TestSimpleUnicode : public ConnectionSetup
{
public:
  /** Suite of tests to be run */
  static CppUnit::Test* suite();

  /**
   * Writes exotic (greek phi + beta + kappa) unicode characters in a table and
   * checks that when read back, the data is identical
   */
  void testPBK();

  /**
   * Writes phi + beta + kappa + zero + kappa in a table and checks that data
   * is identical when read back.<br>
   * This is is even more evil than #testPBK() because of the zero
   * (see SEQUOIA-133)<br>
   * <b>Warning</b>This test will fail at least against mysql and postgresql
   * (and is disabled when <code>CAROB_TEST_USE_MYSQL</code> is defined)
   */
  void testPBKNull();

  /**
   * Checks Latin1 exotic (with french accents) characters read/writes
   */
  void testLatin1CodeSubset();

  /**
   * Check that writing invalid unicode characters throws exception
   */
  void testInvalidUnicode();

};

#endif /*TESTSIMPLEUNICODE_H_*/
